;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "flycheck" "20260320.1715"
  "On-the-fly syntax checking."
  '((emacs "27.1")
    (seq   "2.24"))
  :url "https://github.com/flycheck/flycheck"
  :commit "0e5eb8300d32fd562724216c19eaf199ee1451ab"
  :revdesc "0e5eb8300d32"
  :keywords '("convenience" "languages" "tools")
  :authors '(("Sebastian Wiesner" . "swiesner@lunaryorn.com"))
  :maintainers '(("Clément Pit-Claudel" . "clement.pitclaudel@live.com")
                 ("fmdkdd" . "fmdkdd@gmail.com")
                 ("Bozhidar Batsov" . "bozhidar@batsov.dev")))
